'use strict'
const path = require('path')
const fs = require('fs')

function resolve(dir) {
  return path.join(__dirname, dir)
}


// If your port is set to 80,
// use administrator privileges to execute the command line.
// For example, Mac: sudo npm run
// You can change the port by the following methods:
// port = 9528 npm run dev OR npm run dev --port = 9528
const port = process.env.port || process.env.npm_config_port || 9528 // dev port

// All configuration item explanations can be find in https://cli.vuejs.org/config/
module.exports = {
  /**
   * You will need to set publicPath if you plan to deploy your site under a sub path,
   * for example GitHub Pages. If you plan to deploy your site to https://foo.github.io/bar/,
   * then publicPath should be set to "/bar/".
   * In most cases please use '/' !!!
   * Detail: https://cli.vuejs.org/config/#publicpath
   */
  publicPath: './',
  outputDir: 'dist',
  assetsDir: 'static',
  lintOnSave: process.env.NODE_ENV === 'development',
  productionSourceMap: false,
  devServer: {
    port: port,
    open: true,
    overlay: {
      warnings: false,
      errors: true
    }
  },
  configureWebpack: {
    // provide the app's title in webpack's name field, so that
    // it can be accessed in index.html to inject the correct title.
    resolve: {
      alias: {
        '@': resolve('src')
      }
    },
    devServer: {
      proxy: {
        // "^/user": {target: "http://192.168.58.137:10086"},
        "^/(user|goods|goodsTypes|order|orderItem|rooms|room)/": { target: "http://192.168.43.46:10086" },
        "^/.*": { target: "http://116.63.32.160:8085" },
      },
    }
  },
  chainWebpack(config) {
    // it can improve the speed of the first screen, it is recommended to turn on preload
    config.plugin('preload').tap(() => [
      {
        rel: 'preload',
        // to ignore runtime.js
        // https://github.com/vuejs/vue-cli/blob/dev/packages/@vue/cli-service/lib/config/app.js#L171
        fileBlacklist: [/\.map$/, /hot-update\.js$/, /runtime\..*\.js$/],
        include: 'initial'
      }
    ])

    // when there are many pages, it will cause too many meaningless requests
    config.plugins.delete('prefetch')

    // set svg-sprite-loader
    config.module
      .rule('svg')
      .exclude.add(resolve('src/icons'))
      .end()
    config.module
      .rule('icons')
      .test(/\.svg$/)
      .include.add(resolve('src/icons'))
      .end()
      .use('svg-sprite-loader')
      .loader('svg-sprite-loader')
      .end()

    config
      .when(process.env.ANALYZER == 'true', config => {
        const BundleAnalyzerPlugin = require('webpack-bundle-analyzer').BundleAnalyzerPlugin
        config.plugin('webpack-bundle-analyzer').use(BundleAnalyzerPlugin).tap(() => [
          {
            analyzerPort: "auto"
          }
        ])
      })

    config
      .when(process.env.NODE_ENV !== 'development',
        config => {
          config
            .plugin('ScriptExtHtmlWebpackPlugin')
            .after('html')
            .use('script-ext-html-webpack-plugin', [{
              // `runtime` must same as runtimeChunk name. default is `runtime`
              inline: /runtime\..*\.js$/
            }])
            .end()
          config
            .optimization.splitChunks({
              chunks: 'all',
              cacheGroups: {
                libs: {
                  name: 'libs',
                  priority: 50,
                  chunks: 'initial',
                },
                elementUI: {
                  name: 'elementUI', // split elementUI into a single package
                  priority: 40,
                  test: /[\\/]node_modules[\\/]_?element-ui(.*)/,
                },
                avue: {
                  name: 'avue', // split avue into a single package
                  priority: 41,
                  test: /[\\/]node_modules[\\/]@smallwei(.*)/,
                  reuseExistingChunk: true
                },
                utils: {
                  name: 'utils',
                  test: /([\\/]src[\\/]utils)|lodash|axios|crypto-js/,
                  priority: 30,
                },
                styles: {
                  name: 'styles',  // pack all remaining style files
                  test: /\.(css|scss)$/,
                  priority: 45,
                  reuseExistingChunk: true
                },
              }
            })
        }
      )
  }
}
